@@ -588,7 +588,7 @@ class EdgeFunction(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="functionArn")
     def function_arn(self) -> builtins.str:
-        '''The ARN fo the function.'''
+        '''The ARN of the function.'''
         return typing.cast(builtins.str, jsii.get(self, "functionArn"))
 
     @builtins.property # type: ignore[misc]
